#!/bin/bash
#-------------------------------------------------------------------------------
# Esmeralda4Mac by A.Filhol june 2015 - March 2016 - July 2020
# Bundle "Esmeralda4Mac" - shell script (launcher.sh)
# /MacOS/Esmeralda4Mac: a C binary which calls the current shell script (launcher.sh)
# /Resources/launcher.sh : shell script which launches Esmeralda.
# /Resources: contains the Fortran binaries (Esmeralda and others) and related data folders
#----- actions ---
# 1- Set the default X11 font
# 2- Eliminate the error message: "Fontconfig warning: ignoring UTF-8: not a valid region tag"
# 3- Get the path to the bundle
# 4- Set environment variable: LAUESUITE
# 5- Set environment variable: PATH
# 6- Launch Esmeralda
# 7- Stop Esmeralda4Mac without closing the Terminal window
#----- Useful info --- 
# Esmeralda preferences (i.e. Working directory)
# They are saved through Windows "registery" in file ".winter.reg"
# see esmeralda_utilities.f90: SaveAllRegistry, ReadRegistry, WriteRegistry, Load_Preferences
# see Winteracter "Programming Reference"
#    -> "Subroutine Reference" -> "Operating System Interface" -> "Registry manipulation"
#-------------------------------------------------------------------------------


echo " "
echo "    *********************************************"
echo "    ************ Please WAIT ! ******************"
echo "    *** At 1st launch, Apple's security check ***"
echo "    *** may be quite long                     ***"
echo "    *********************************************"
parentDir="$(dirname "$0")"
cd "$parentDir"
#echo "progression bar: $PWD/progression_bar.sh"
./progression_bar.sh &   # asynchroneous launch

#---- Debug yes/no
IFDEBUG=no

if [ "$IFDEBUG" == "yes" ]; then
    echo "ESMERALDA - launcher.sh - debug"
    echo "Cur.Dir.  : "$PWD > ~/debug_launcher.txt
    echo "arg 0     : " $0 >> ~/debug_launcher.txt
fi

#----------------------------------------------------
#--- Selecting a font for Winteracter ---------------
#--- A. Filhol and J. Gonzalez Platas : March 2016
#----------------------------------------------------
POLICENAME="Verdana"
POLICECODE="Wint*xftName"
XRESOURCES=".Xresources"
XDEFAULTS=".Xdefaults"
XFILE="$XRESOURCES"
#---- Working directory
cd ~
if [ "$IFDEBUG" == "yes" ]; then
  echo "Selecting a font for Winteracter"
  echo "New     WD = "`pwd`
fi
#---- .Xresources or .Xdefaults already exist
if [[ -f "$XRESOURCES"  ||  -f "$XDEFAULTS" ]]; then
  #-- Select the existing file
  if [ -f "$XDEFAULTS" ]; then
    XFILE="$XDEFAULTS"
  fi
  #	echo "trouvé : $XFILE"
  #-- Delete the line if already present
  sed -i "" "/xftName/d" "$XFILE"
  #-- Append the new line
  echo "$POLICECODE : $POLICENAME" >> $XFILE
  #---- .Xresources or .Xdefaults does not exist
else
  #	echo "pas trouvé"
  echo "$POLICECODE : $POLICENAME" > $XFILE
fi
#
if [ "$IFDEBUG" == "yes" ]; then
  echo "File processed: $XFILE and selected font:"
  echo `cat $XFILE` | grep -E -o ".{0,5}xftName.{0,15}"
  #echo `cat $XFILE`
fi
#
#---- Make the change active
/opt/X11/bin/xrdb $XFILE
#
#---- Eliminating error message: "Fontconfig warning: ignoring UTF-8: not a valid region tag"
#---- https://stackoverflow.com/questions/24712158/
#----   how-to-solve-imagemagicks-fontconfig-warning-ignoring-utf-8-not-a-valid-regi
LC_CTYPE=""
export LC_CTYPE

#---- get the path of the application bundle
#SCRIPTPATH=$(echo $0 | perl -p -e 's/\/MacOS\/launcher.sh//g')
SCRIPTPATH=$(echo $0 | perl -p -e 's/\/Resources\/launcher.sh//g')
if [ "$IFDEBUG" == "yes" ]; then
    echo "SCRIPTPATH: "$SCRIPTPATH >> ~/debug_launcher.txt
fi

#---- set default directory to that path
cd "$SCRIPTPATH"
if [ "$IFDEBUG" == "yes" ]; then
    echo "Cur.Dir.  : "$PWD >> ~/debug_launcher.txt
fi

#---- set environment variables "LAUESUITE"
LAUESUITE="$SCRIPTPATH/Resources"
export LAUESUITE
if [ "$IFDEBUG" == "yes" ]; then
    echo "LAUESUITE : "$LAUESUITE >> ~/debug_launcher.txt
fi

#---- Path required by auxiliary applications with Terminal input/output
PATH=$PATH:$LAUESUITE
export PATH
if [ "$IFDEBUG" == "yes" ]; then
echo "PATH : "$PATH >> ~/debug_launcher.txt
fi

#---- launches the Fortran binary "/Resources/Esmeralda"
#---- i.e, the Winteracter application "Esmeralda"
LAUNCHCMD="$SCRIPTPATH/Resources/Esmeralda"
if [ "$IFDEBUG" == "yes" ]; then
    echo "LAUNCHCMD : "$LAUNCHCMD >> ~/debug_launcher.txt
fi
echo "    *********************************************"

#=======================================
$LAUNCHCMD    # Esmeralda launch command
#=======================================

#----------------------------------- Tests --------------------------------------
#---- Unhide the Terminal window by moving and resizing it
#---- Unfortunately, this will occur only after Esmeralda stops
#
#  osascript -e "tell application \"Terminal\"" -e "activate" -e "set the bounds of the front window to {15, 35, 400, 600}" -e "end tell"
#  osascript -e 'tell application "Finder"' -e "activate" -e "display dialog \"hello\"" -e 'end tell'
#
#---- Open TextEdit and pipe it stdout
#---- Unfortunately, this will occur only after Esmeralda stops, while we want a "live" output
# "$LAUNCHCMD | open -tf"
#---- This does not helps since it stops Esmeralda
# "$LAUNCHCMD > /dev/null 2>&1"
#
#-------------------------------------------------------------------------------

#---- Exit from Esmeralda will close Xquartz but not the Terminal window
#---- thus we ask Terminal to close its front window only since other Terminal windows might be in use
osascript -e 'tell application "Terminal" to close front window'

#---- The end
if [ "$IFDEBUG" == "yes" ]; then
echo "End of script" >> ~/debug_launcher.txt
fi
